# 🧮 Bookshelf Math

This datapack brings the beautiful world of mathematics to Minecraft, offering a variety of mathematical functions and operations.

> “Mathematics has very subtle inventions that can be of great service, both to satisfy the curious and to facilitate all arts and reduce the labor of men.”
>
> -- René Descartes

For more details and usage examples, check out the Bookshelf [documentation](https://docs.mcbookshelf.dev/en/latest/modules/math.html).


## 📖 About Bookshelf

This module is part of the [Bookshelf Library](https://docs.mcbookshelf.dev/en/latest/index.html), a modular library datapack designed to simplify complex systems in Minecraft. Explore the full range of modules and discover how Bookshelf can simplify your Minecraft creations!
